@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ipp" "0.8"
+(define-package "ipp" "20251124.718"
   "Implementation of the Internet Printing Protocol."
-  '((cl-lib "0.5")
-    (emacs  "24.1"))
+  '((plz   "0.9")
+    (emacs "28.1"))
   :url "https://github.com/emarsden/ipp-el"
-  :commit "cb26728c32ab78ae926791388a864f528eb7c800"
-  :revdesc "cb26728c32ab"
+  :commit "8210d8a276ff4dfb67e3a2b4594a67be095edd45"
+  :revdesc "8210d8a276ff"
   :keywords '("printing" "hardware")
   :authors '(("Eric Marsden" . "eric.marsden@risk-engineering.org"))
   :maintainers '(("Eric Marsden" . "eric.marsden@risk-engineering.org")))
