@@ -4,9 +4,9 @@
 ;;; Copyright: (C) 2001-2025  Eric Marsden
 ;;; Keywords: printing, hardware
 ;;; URL: https://github.com/emarsden/ipp-el
-;; Package-Version: 0.8
-;; Package-Revision: cb26728c32ab
-;;; Package-Requires: ((cl-lib "0.5") (emacs "24.1"))
+;; Package-Version: 20251124.718
+;; Package-Revision: 8210d8a276ff
+;;; Package-Requires: ((plz "0.9") (emacs "28.1"))
 ;;
 ;;     This program is free software; you can redistribute it and/or
 ;;     modify it under the terms of the GNU General Public License as
@@ -132,7 +132,7 @@
   :group 'comm)
 
 (defcustom ipp-default-printer nil
-  "If non-nil, the default value for the IPP printer preselected when calling `ipp-print'.
+  "If non-nil, the default IPP printer preselected when calling `ipp-print'.
 Examples: ipp://hostname:631/path or https://192.168.1.10:631/ipp/port."
   :type '(choice string (const nil))
   :group 'ipp-printing)
@@ -142,6 +142,21 @@ Examples: ipp://hostname:631/path or https://192.168.1.10:631/ipp/port."
   :type 'string
   :group 'ipp-printing)
 
+(defcustom ipp-user-agent "ipp.el"
+  "The User-Agent header to send in IPP requests."
+  :type 'string
+  :group 'ipp-printing)
+
+(defcustom ipp-connect-timeout 20.0
+  "Timeout in seconds when connecting to an IPP server."
+  :type 'float
+  :group 'ipp-printing)
+
+(defcustom ipp-request-timeout 30.0
+  "Timeout in seconds for requests sent to an IPP server."
+  :type 'float
+  :group 'ipp-printing)
+
 
 (defvar ipp--request-id 42)
 
@@ -181,6 +196,8 @@ otherwise. PORT defaults to 631 if not specified."
     (#x22 (eql (ipp-demarshal-int value-length) 1))
     ;; Enum
     (#x23 (ipp-demarshal-int value-length))
+    ;; String
+    (#x30 (ipp-demarshal-string value-length))
     ;; DateTime, encoded as an OCTET-STRING consisting of eleven octets whose contents are defined
     ;; by "DateAndTime" in RFC 1903
     (#x31 (let ((year (ipp-demarshal-int 2))
@@ -396,7 +413,10 @@ otherwise. PORT defaults to 631 if not specified."
                              (error "Not an IPP URL: %s" printer-uri)))))
     (plz 'post massaged-uri
       :headers '(("Content-Type" . "application/ipp")
+                 ("User-agent" . ipp-user-agent)
                  ("Connection" . "close"))
+      :connect-timeout ipp-connect-timeout
+      :timeout ipp-request-timeout
       :body request
       :body-type 'binary
       :as #'ipp-decode-body)))
@@ -417,17 +437,17 @@ The printer name should be of the form ipp://host:631/ipp/port1."
 
 (defun ipp-print (printer content)
   "Print CONTENT to IPP-capable network device PRINTER.
-CONTENT must be in a format understood by your printer, such as PDF, Postscript
-or PCL.
-The printer name should be of the form ipp://host:631/ipp/port1."
+CONTENT must be in a format understood by your printer, such as PDF,
+Postscript or PCL. The printer name should be of the form
+ipp://host:631/ipp/port1."
   (ipp-get printer content))
 
 ;;;###autoload
 (defun ipp-print-file (filename printer)
   "Print FILENAME to the IPP-capable network device PRINTER.
-FILENAME must be in a format understood by your printer, such as PDF, Postscript
-or PCL.
-The printer name should be of the form ipp://host:631/ipp/port1."
+FILENAME must be in a format understood by your printer, such as PDF,
+Postscript or PCL. The printer name should be of the form
+ipp://host:631/ipp/port1."
   (interactive
    (list
     (expand-file-name (read-file-name "IPP print file: "))
@@ -437,12 +457,11 @@ The printer name should be of the form ipp://host:631/ipp/port1."
 
 ;;;###autoload
 (defun ipp-print-region (buffer printer &optional start end)
-  "Print BUFFER region from START to END to IPP-capable network device PRINTER.
-BUFFER contents must be in a format understood by your printer, such as PDF, Postscript
-or PCL.
-If START is nil, it defaults to beginning of BUFFER.
-If END is nil, it defaults to end of BUFFER.
-The PRINTER URI should be of the form ipp://host:631/ipp/port1."
+  "Print BUFFER region from START to END to IPP-capable device PRINTER.
+BUFFER contents must be in a format understood by your printer, such as
+PDF, Postscript or PCL. If START is nil, it defaults to beginning of
+BUFFER. If END is nil, it defaults to end of BUFFER. The PRINTER URI
+should be of the form ipp://host:631/ipp/port1."
   (interactive "bIPP print buffer (region): \nsPrinter URI: ")
   (ipp-print printer
 	     (ipp-marshal-print-job-request-region printer buffer start end)))
@@ -450,9 +469,9 @@ The PRINTER URI should be of the form ipp://host:631/ipp/port1."
 ;;;###autoload
 (defun ipp-print-buffer (buffer printer)
   "Print BUFFER to IPP-capable network device PRINTER.
-BUFFER contents must be in a format understood by your printer, such as PDF, Postscript
-or PCL.
-The printer name should be of the form ipp://host:631/ipp/port1."
+BUFFER contents must be in a format understood by your printer, such as
+PDF, Postscript or PCL. The printer name should be of the form
+ipp://host:631/ipp/port1."
   (interactive
    (list
     (read-buffer "IPP print buffer region: ")
